# set version information for Recital
#
recital_setversion()
{
  major="24"
  minor="98"
  release="2"
  version="${major}.${minor}"
  ver="${major}${minor}"
  fullver="${major}.${minor}.${release}"
}
#
# set platform
#
recital_setplatform ()
{
  if [ ! -f /etc/recital.d/.platform ];then
  	if [ -n "${1}" ];then
  	  echo $1 > /etc/recital.d/.platform
	  platform=`cat /etc/recital.d/.platform`
	  DB_PLATFORM=${platform}
    fi
  else
    platform=`cat /etc/recital.d/.platform`
    DB_PLATFORM=${platform}
  fi
}
#
# Change the permissions
#
# $1 = permisions
# $2 = list of files
#
recital_chmod()
{
  for i in $2
  do
    chmod $1 $i
  done
}
#
# Change the permissions
#
# $1 = permisions
# $2 = list of files
#
recital_mkdir()
{
  for i in $1
  do
    if [ ! -d ${DB_ROOT}$i ]; then
      mkdir ${DB_ROOT}$i
      chmod 777 ${DB_ROOT}$i
    fi
  done
}
#
# remove directories from specified list
#
recital_rmdir ()
{
  for i in $1
  do
    if [ -d ${DB_ROOT}${i} ]; then
      rmdir ${i}  > /dev/null 2>&1
    fi
  done
}
#
# remove directories from specified list
#
recital_removedirs ()
{
  recital_rmdir "bin conf"
  recital_rmdir "data/southwind data/odbc_test data/jdbc_test data"
  recital_rmdir "debug doc drivers error extensions"
  recital_rmdir "examples/jdbc examples/odbc examples/gateways/pgsql examples/gateways/mysql examples/gateways/oracle examples/gateways/recital examples/gateways  examples"
  recital_rmdir "man include images lib"
  recital_rmdir "licenses/rtd licenses/rvd licenses/rus licenses/rwd licenses/rds licenses"
  recital_rmdir "log mirage/mirage_demo mirage"
  recital_rmdir "setup terminals webroot/recital/images webroot/recital/scripts webroot/recital webroot"
}
#
# add shared links and directories
#
# $1 = list of files
#
recital_create_recitallink()
{
  recital_mkdir "users debug error log data/jdbc_test"
  cd ${1}
  cd ../
  if [ -d ./recital ]; then
    rm -rf ./recital
  fi
  if [ ! -d ./recital ]; then
    ln -s ${installdir} ./recital
  fi
  cd ${1}
  recital_link "dbinstall dbuninstall"
  if [ -f etc/recital.d/recital.conf ];then
  	rm /etc/recital.d/recital.conf  2>/dev/null 1> /dev/null
  fi
  cp ${1}/conf/recital.conf /etc/recital.d/recital.conf 2>/dev/null 1> /dev/null
  rm ${1}/conf/recital.conf 2>/dev/null 1> /dev/null 
  if [ -f /etc/recital.d/recital.conf ];then
    ln -s /etc/recital.d/recital.conf ${1}/conf/recital.conf 
  fi
  if [ -h /usr/bin/recital ];then
  	rm /usr/bin/recital
  fi
  ln -s ${1}/bin/db /usr/bin/recital
  for file in `ls ${1}/man/*`
  do
    ofile=`basename ${file}`
    ln -sf ${file} /usr/share/man/man1/${ofile}
  done
  
}
#
# remove file
#
# $1 = list of files
#
recital_rm()
{
  for i in $1
  do
    if [ -f ${2}${i} -o -h ${2}${i} ];then
      rm ${2}${i}
    fi
  done
}
#
# create link
#
# $1 = list of files
#
recital_link()
{
  for i in $1
  do
    if [ -f ${DB_ROOT}bin/$i ];then
      rm /usr/bin/$i  2>/dev/null 1> /dev/null
      if [ -z "$LN" ];then
        ln -s ${DB_ROOT}bin/$i /usr/bin/$i  2>&1
        if [ $? != 0 ];then
          LN="cp"
          cp $i /usr/bin/$i > /dev/null 2>&1
        else
          LN="ln -s"
        fi
      else
        ${LN} ${DB_ROOT}bin/$i /usr/bin/$i  2>&1
      fi
    fi
  done
}
#
# Remove files used for the installation
#
# $1 is the directory where Recital is installed
# $2 is the product version that was installed
#
recital_removeinstallfiles ()
{
  recital_rm ${DB_ROOT}${product}${platform}.tar
  if [ "$platform" = "047" ];then
     exit 0;
  fi
  cd $1
  for file in `ls ${2}-*.tar`
  do
    recital_rm $file
  done
  for file in `ls setup/${2}.rpm`
  do
    recital_rm $file
  done
}
#
# Remove files used for install and uninstall
#
# $1 is the product version that was installed
#
recital_removesetupfiles ()
{
  if [ -f ${DB_ROOT}setup/uninst${1}.lis ];then
    for files in `cat ${DB_ROOT}setup/uninst${1}.lis`
    do
      recital_rm ${files} "${DB_ROOT}"
    done
  fi
  recital_rm "setup${1}.sh install${1}.sh uninst${1}.lis" "${DB_ROOT}setup/"
  recital_rm "recital${ver}${1}.sh ${2}" "/usr/bin/"
  if [ -z "${UNINSTALLALL}" ];then
    recital_rm "odbcinst.ini" "${DB_ROOT}setup/"
    recital_rm "dbinstall dbuninstall dbintegrity" "/usr/bin/"
    recital_rm "dbinstall dbuninstall dbintegrity" "${DB_ROOT}bin/"
    recital_rm "recfuncs.sh dbprint dbusers" "${DB_ROOT}bin/"
    recital_rm "rtusers.db users.db" "${DB_ROOT}licenses/"
    recital_rm "recital.conf config.db" "${DB_ROOT}conf/"
    recital_rm ".platform .root recital.conf" "/etc/recital.d/"
    recital_rm "recital.1 recitalserver.1 recitaladmin.1 recitalreplication.1 recitalweb.1" "/usr/shared/man/man1/"
    recital_rm "dbdbf dbdbx dbdbt dbndx recitaladmin recitalserver recitalreplication" "${DB_ROOT}bin/"
    rmdir /etc/recital.d  2>/dev/null 1> /dev/null
  else
    recital_rm ".installed${1}" "/etc/recital.d/"
 fi
}
#
# Confirm action
#
# $1 product name
# $2 action
# $3 default action
# $4 exit if reply matches
#
recital_confirm_action ()
{
  if [ "${silent}" = "1" ]; then
     reply="y"
  else
    reply=`echo ${3} | tr [A-Z]  [a-z]`
    ${echonl_b} "${2} Recital ${version} ${1} (y/n) [${reply}] : $echonl_a"
    read reply
    if [ -z "${reply}" ];then
      reply="${3}"
    else
      reply=`echo ${reply} | tr [A-Z]  [a-z]`
    fi
    if [ "${reply}" = "${4}" ];then
      exit
    else
      echo "${2}ing Recital ${version} ${1}."
    fi
  fi
}
#
# extract the files
#
# $1 is the directory where Recital is installed
# $2 is the product name of the installed to be extracted
#
recital_extractfile ()
{
  if [ "${linux}" = "1" ]; then
    gunzip -f ./${2}${platform}.tar.gz 2> /dev/null
  else
    uncompress ./${2}${platform}.tar.Z 2> /dev/null
  fi
  file=`ls ${2}*.tar`
  tarloc=`pwd`
  if [ -n "$1" ];then
    cd $1
  fi
  tar xvf ${tarloc}/${2}${platform}.tar > /dev/null
}
#
# Setup Recital global environment file
#
# $1 is the directory where Recital is installed
# $2 is the product name
#
recital_globalenv ()
{
  if [ -z "${ver}" ];then
    recital_setversion
  fi
  if [ -z "$1" ];then
    DB_ROOT=`pwd`/
  else
    DB_ROOT=`dirname $1`"/"`basename $1`"/"
  fi
  if [ ! -d /etc/recital.d ];then
  	mkdir /etc/recital.d
  fi
  echo "${DB_ROOT}"	> /etc/recital.d/.root
  if [ -f ${DB_ROOT}setup/.platform ];then
  	cp ${DB_ROOT}setup/.platform  /etc/recital.d/.platform  2> /dev/null
  fi
  recital_setplatform ${ROI_MACHINE}
  if [ -z "$platform" ];then
    echo "Installation platform not found."
    echo "Operation cancelled."
    exit -1
  fi
}
#
# Add to rpm
#
# $1 is the product name
#
recital_addrpm()
{
  rpm -i ${DB_ROOT}setup/${1}-${fullver}.rpm
}
#
# Delete from rpm
#
# $1 is the product name
#
recital_delrpm()
{
  if [ -n "${1}" ];then
    rpminstalled=`rpm -qa | grep ${1}-${version}-${release}`
    if [ -n "${rpminstalled}" ];then
      rpm -e ${1}-${version}-${release}
    fi
  fi
}
#
# Add a menu shortcut
#
recital_addmenu()
{
  if [ "${linux}" = "1" ]; then
  #
  # Create shortcut for Gnome
  #
  if [ -d /usr/share/applications ];then
    if [ -f ${HOME}/Desktop/Recital.desktop ];then
      cp ${HOME}/Desktop/Recital.desktop /usr/share/applications/Recital.desktop 2> /dev/null
    fi
    if [ -f ${HOME}/.gnome-desktop/Recital.desktop ];then
      cp ${HOME}/.gnome-desktop/Recital.desktop /usr/share/applications/Recital.desktop 2> /dev/null
    fi
  fi
  #
  # Create shortcut for KDE
  #
  if [ -f ${HOME}/Desktop/Recital.kdelnk ];then
    if [ -d /usr/share/applnk/ ];then
      if [ ! -d /usr/share/applnk/Programming ];then
        mkdir /usr/share/applnk/Programming
      fi
      cp ${HOME}/Desktop/Recital.kdelnk /usr/share/applnk/Programming/Recital.kdelnk 2> /dev/null
    fi
    if [ -d /usr/share/applnk-redhat/ ];then
      if [ ! -d /usr/share/applnk-redhat/Programming ];then
        mkdir /usr/share/applnk-redhat/Programming
      fi
      cp ${HOME}/Desktop/Recital.kdelnk /usr/share/applnk-redhat/Programming/Recital.kdelnk 2> /dev/null
    fi
  fi
  fi
}
#
# Delete desktop shortcuts
#
recital_delmenu()
{
  if [ "${linux}" = "1" ]; then
  if [ -f /usr/share/applications/Recital.desktop ];then
    rm /usr/share/applications/Recital.desktop 2> /dev/null
  fi
  if [ -f /usr/share/applnk/Programming/Recital.kdelnk ];then
    rm /usr/share/applnk/Programming/Recital.kdelnk 2> /dev/null
  fi
  if [ -f /usr/share/applnk-redhat/Programming/Recital.kdelnk ];then
    rm /usr/share/applnk-redhat/Programming/Recital.kdelnk 2> /dev/null
  fi
  fi
}
#
# Delete a desktop shortcut
#
# $1 is the directory where Recital is installed
# $2 is the flag to install the link for all users
#
recital_addshortcut()
{
  if [ "${linux}" = "1" ]; then
  #
  # Create shortcut for Gnome
  #
  echo "[Desktop Entry]" 			>  /tmp/$$
  echo "Type=Application"	 		>> /tmp/$$
  echo "Version=1.0"		 	>> /tmp/$$
  echo "Name=Recital ${version}\nDeveloper"		 		>> /tmp/$$
  echo "Comment=Run Recital ${version} Developer"	>> /tmp/$$
  echo "Icon=${1}/images/recital_icon48x48.png"		>> /tmp/$$
  echo "Exec=db -g"				>> /tmp/$$
  echo "Terminal=false"				>> /tmp/$$
  echo "Categories=GTK;GNOME;Development;"	>> /tmp/$$
  if [ -d $HOME/.gnome-desktop ];then
     cp /tmp/$$ ${HOME}/.gnome-desktop/Recital.desktop 2> /dev/null
     gnomeshortcut=${HOME}/.gnome-desktop/Recital.desktop
     gnomepath=.gnome-desktop
  fi
  if [ -d $HOME/Desktop ];then
     cp /tmp/$$ ${HOME}/Desktop/Recital.desktop 2> /dev/null
     gnomeshortcut=${HOME}/Desktop/Recital.desktop
     gnomepath=Desktop
  fi
  if [ -d /opt/kde3/share/applnk ];then
    cp /tmp/$$ /opt/kde3/share/applnk/Recital.desktop 2> /dev/null
     gnomeshortcut=/opt/kde3/share/applnk/Recital.desktop
  fi
  #
  # Create shortcut for KDE
  #
  echo "# KDE Config File"				>  /tmp/$$
  echo "[KDE Desktop Entry]"				>> /tmp/$$
  echo "Comment[C]=Run Recital ${version} Developer"	>> /tmp/$$
  echo "SwallowTitle="					>> /tmp/$$
  echo "SwallowExec="					>> /tmp/$$
  echo "BinaryPattern="					>> /tmp/$$
  echo "MimeType="					>> /tmp/$$
  echo "Exec=db -g"					>> /tmp/$$
  echo "Icon=${1}images/recital_icon48x48.png"			>> /tmp/$$
  echo "TerminalOptions="				>> /tmp/$$
  echo "Type=Application"				>> /tmp/$$
  echo "Terminal=0"					>> /tmp/$$
  echo "Name=Recital ${version}\nDeveloper"		>> /tmp/$$
  if [ -d $HOME/Desktop ];then
     if [ ! -f ${HOME}/Desktop/Recital.desktop ];then
		 cp /tmp/$$ ${HOME}/Desktop/Recital.desktop 2> /dev/null
     fi
     kdeshortcut=${HOME}/Desktop/Recital.kdelnk
     kdepath=Desktop
  fi
  rm /tmp/$$
  #
  # add shortcut for all existing users
  #
  if [ "$2" = "AnyOne" ];then
    for i in `cat /etc/passwd | cut -f6,7 -d:`
    do
      var1=`echo $i | grep -v nologin | grep -v shutdown | grep -v sync | grep -v halt`
      if [ -n "$var1" ];then
        var2=`echo $var1 | cut -f2 -d:`
        if [ -n "$var2" ];then
          homepath=`echo $var1 | cut -f1 -d:`
          if [ -n "${gnomeshortcut}" ];then
            if [ ! -d ${homepath}/${gnomepath} ];then
              mkdir ${homepath}/${gnomepath}
            fi
            cp ${gnomeshortcut} $homepath/${gnomepath}/ 2> /dev/null
			username=`echo $homepath | awk -F/ '{print $3}'`
			chown $username $homepath/${gnomepath}/Recital.desktop
          fi
          if [ -n "${kdeshortcut}" ];then
            if [ ! -d ${homepath}/${kdepath} ];then
              mkdir ${homepath}/${kdepath}
            fi
            cp ${kdeshortcut} $homepath/${kdepath}/ 2> /dev/null
			username=`echo $homepath | awk -F/ '{print $3}'`
			chown $username $homepath/${kdepath}/Recital.kdelnk
          fi
        fi
      fi
    done
  fi
  fi
}
#
# Delete desktop shortcuts
#
recital_delshortcut()
{
  if [ "${linux}" = "1" ]; then
  for i in `cat /etc/passwd | cut -f6,7 -d:`
  do
    var1=`echo $i | grep -v nologin | grep -v shutdown | grep -v sync | grep -v halt`
    if [ -n "$var1" ];then
      var2=`echo $var1 | cut -f2 -d:`
      if [ -n "$var2" ];then
        homepath=`echo $var1 | cut -f1 -d:`
        if [ -f ${homepath}/Desktop/Recital.desktop ];then
          rm ${homepath}/Desktop/Recital.desktop 2> /dev/null
        fi
        if [ -f ${homepath}/.gnome-desktop/Recital.desktop ];then
          rm ${homepath}/.gnome-desktop/Recital.desktop 2> /dev/null
        fi
        if [ -f ${homepath}/Desktop/Recital.kdelnk ];then
          rm ${homepath}/Desktop/Recital.kdelnk 2> /dev/null
        fi
      fi
    fi
  done
  fi
}
#
# install recital shared library path in ldconfig
#
recital_addldconfig()
{
  if [ "${linux}" = "1" ]; then
    if [ -d /etc/ld.so.conf.d ]; then
        echo "${DB_ROOT}lib"  >  /etc/ld.so.conf.d/recital.conf
    elif [ -f /etc/ld.so.conf ]; then
      path=`grep "${DB_ROOT}" /etc/ld.so.conf`
      if [ -z "${path}" ]
      then
        cat /etc/ld.so.conf > /tmp/$$
        echo "${DB_ROOT}lib"  >> /tmp/$$
        mv /etc/ld.so.conf  /etc/ld.so.conf.bck
        mv /tmp/$$ /etc/ld.so.conf
      fi
    else
      echo "${DB_ROOT}lib"  > /etc/ld.so.conf
    fi
    ldconfig
  fi
}
#
# remove recital shared library path in ldconfig
#
recital_delldconfig()
{
  if [ "${linux}" = "1" ]; then
    if [ -f /etc/ld.so.conf.d/recital.conf ]; then
	  rm /etc/ld.so.conf.d/recital.conf
    elif [ -f /etc/ld.so.conf ]; then
      grep -v "${DB_ROOT}" /etc/ld.so.conf > /tmp/$$
      mv /etc/ld.so.conf  /etc/ld.so.conf.bck
      mv /tmp/$$ /etc/ld.so.conf
    fi
    ldconfig
  fi
}
#
# Get process ID.
#
# $1 process name
# $2 exclude db_rsiserver
#
recital_getprocess()
{
  if [ "$1" = "*" ];then
    process=db_
  else
    process=`echo db_${1} | cut -c 1-8`
  fi
  if [ -z "${process}" ];then
    PROCESS=""
  elif [ -z "$2" ];then
    PROCESS=`ps -ef | grep "${process}" | grep -v "grep"  | awk -F" " '{print $2}'`
  else
    PROCESS=`ps -ef | grep "${process}" | grep -v "grep" | grep -v db_rsi | awk -F" " '{print $2}'`
  fi
}
#
# set shared library path
#
recital_set_shared_library_path()
{
  if [ -z "$LD_LIBRARY_PATH" ];then
    if [ -d /usr/X/lib ];then
      LD_LIBRARY_PATH=:/usr/X/lib/;export LD_LIBRARY_PATH
    else
      LD_LIBRARY_PATH=:/usr/lib/;export LD_LIBRARY_PATH
    fi
  fi
  LD_LIBRARY_PATH=${DB_ROOT}lib/:${LD_LIBRARY_PATH};export LD_LIBRARY_PATH
  SHLIB_PATH=${DB_ROOT}lib/:${SHLIB_PATH};export SHLIB_PATH
  if [ -n "$ORACLE_HOME" ];then
    LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${ORACLE_HOME}/lib/;export LD_LIBRARY_PATH
    SHLIB_PATH=${SHLIB_PATH}:${ORACLE_HOME}/lib/;export SHLIB_PATH
  fi
  DYLD_LIBRARY_PATH=${DYLD_LIBRARY_PATH}:${LD_LIBRARY_PATH};export DYLD_LIBRARY_PATH
}
#
# install recital pam file
#
recital_addpamd()
{
  if [ -f /sbin/chkconfig ];then
    if [ -f /etc/pam.d/recital ];then
      rm /etc/pam.d/recital
    fi
    if [ -d /etc/pam.d ];then
      if [ "`uname -s`" = "Darwin" ]; then
        cp ${DB_ROOT}setup/recital.osx.pam /etc/pam.d/recital
      elif [ -f /lib/security/pam_unix2.so ];then
        cp ${DB_ROOT}setup/recital.unix2.pam /etc/pam.d/recital
      else
        cp ${DB_ROOT}setup/recital.pam /etc/pam.d/recital
      fi
    fi
  else
    if [ -f /etc/pam.d/recital ];then
      rm /etc/pam.d/recital
    fi
    if [ -d /etc/pam.d ];then
      if [ -f /lib/security/pam_unix2.so ];then
        if [ -f ${DB_ROOT}setup/recital.unix2.pam ];then
          cp ${DB_ROOT}setup/recital.unix2.pam /etc/pam.d/recital
        fi
      else
        if [ -f ${DB_ROOT}setup/recital.pam ];then
          cp ${DB_ROOT}setup/recital.pam /etc/pam.d/recital
        fi
      fi
    fi
  fi
}
#
# install recital server init.d file
#
recital_addinitd()
{
  if [ -f /sbin/chkconfig ];then
    if [ -d /etc/rc.d ];then
      if [ -d /etc/rc.d/init.d ];then
        if [ -f /etc/rc.d/init.d/${2} ];then
          chkconfig --del ${2} 2> /dev/null
          rm /etc/rc.d/init.d/${2}
        fi
        cp ${DB_ROOT}setup/${1}.rc /etc/rc.d/init.d/${2}
        chmod 755 /etc/rc.d/init.d/${2}
      fi
    elif [ -d /etc/init.d ];then
      if [ -f /etc/init.d/${2} ];then
        chkconfig --del ${2} 2> /dev/null
        rm /etc/init.d/${2}
      fi
      cp ${DB_ROOT}setup/${1}.rc /etc/init.d/${2}
      chmod 755 /etc/init.d/${2}
    fi
    chkconfig --add ${2} 2> /dev/null
  fi
}
#
# remove db_rsibase for /etc/services
#
recital_delrsibase()
{
  port=`grep db_rsibase /etc/services`
  if [ -n "${port}" ];then
    grep -v db_rsibase /etc/services > /tmp/$$
    mv /etc/services /etc/services.bck
    mv /tmp/$$ /etc/services
  fi
}
#
# add db_rsibase for /etc/services
#
recital_addrsibase()
{
  port=`grep db_rsibase /etc/services`
  if [ -z "${port}" ];then
    cat /etc/services > /tmp/$$
    echo "db_rsibase  8001/tcp               # Recital RSI www.recital.com"  >> /tmp/$$
    mv /etc/services /etc/services.bck
    mv /tmp/$$ /etc/services
  fi
}
#
# remove files from specified list
#
# $1 is the file that contains a list of files to remove
# $2 is silent mode, 1 - True, 0 - False
#
recital_removefiles ()
{
  silent=$2
  for i in `cat $1`
  do
    shared=`echo $i | cut -c 1-7`
    if [ "$shared" = "/lib" ];then
	  if [ "${silent}" = "1" ]; then
        reply="y"
      else
        reply="n"
        ${echonl_b} "Do you wish to uninstall the shared file? $i (y/n) [${reply}] : $echonl_a"
        read reply
        if [ -z "$reply" ];then
          reply="n"
        fi
      fi
      if [ "$reply" = "y" -o "$reply" = "Y" ];then
        if [ -d ${DB_ROOT}$i ];then
          rmdir ${DB_ROOT}$i 2> /dev/null
        else
          rm ${DB_ROOT}$i 2> /dev/null
        fi
      fi
    else
      if [ -d ${DB_ROOT}$i ];then
       rmdir ${DB_ROOT}$i 2> /dev/null
      else
       rm ${DB_ROOT}$i 2> /dev/null
      fi
    fi
  done
}
#
# Set system specific variables
#
recital_setprofile ()
{
  fpelicense=0
  linux=0
  if [ -f /etc/lilo.conf ]; then
    linux=1
  fi
  if [ -f /etc/grub.conf ]; then
    linux=1
  fi
  if [ "`uname -s`" = "Linux" ]; then
    linux=1
  fi
  echo -n | grep n  > /dev/null
  if [ $? != 0 ];then
    echonl_b="echo -n"
    echonl_a=""
  else
    echonl_b="echo"
    echo "\c" | grep "\c"  > /dev/null
    if [ $? != 0 ];then
      echonl_a="\c"
    else
      echonl_a=""
    fi
  fi

  if [ "${linux}" = "1" -a "${silent}" != "0" ]; then
    silent=1
  fi

  if [ "${linux}" = "1" ]; then
    packcom="gzip"
    packext="gz"
  else
    echo "1         1" > comp.tst
    rm comp.tst.Z 2> /dev/null
    comptst=`compress comp.tst` 2> /dev/null
    if [ -z "$comptst"  ];then
      packcom="compress"
      packext="Z"
    else
      packcom="pack"
      packext="z"
    fi
    rm comp.tst 2> /dev/null
    rm comp.tst.Z 2> /dev/null
  fi
  case $DB_PLATFORM
  in
  054)
    slext="a"
    ;;
  020)
    slext="sl"
    ;;
  061)
    slext="sl"
    ;;
  063)
    slext="dylib"
    ;;
  *)
    slext="so"
    ;;
  esac
}
  ##########################################################
 ############################################################
##############################################################
#                      FUNCTIONS                             #
##############################################################
 ############################################################
  ##########################################################
#
# Uninstall RCS specific files
dbuninstall_rcd()
{
  cd ${DB_ROOT}setup
  ##############################################################
  # Check for ODBC driver manager installation and uninstall
  ##############################################################
  if [ -f /usr/bin/odbcinst ];then
    odbcinst -u -s -v -n "Recital ODBC test"
    odbcinst -u -v -d -n Recital
  elif [ -f /usr/lib/libodbc.so ];then
    if [ -f /etc/odbcinst.ini ];then
      installed=`grep "\[Recital\]" /etc/odbcinst.ini`
      if [ -z "$installed"  ];then
        grep -vi recital /etc/odbcinst.ini      >> /tmp/$$
        mv /tmp/$$ /etc/odbcinst.ini
      fi
    fi
  elif [ -f /usr/lib/libiodbc.so.2 ];then
    if [ -f /etc/odbcinst.ini ];then
      installed=`grep "\[Recital\]" /etc/odbcinst.ini`
      if [ -z "$installed" ];then
        grep -vi recital /etc/odbcinst.ini      >> /tmp/$$
        mv /tmp/$$ /etc/odbcinst.ini
      fi
      installed=`grep "\[Recital ODBC test\]" /etc/odbc.ini`
      if [ -z "$installed" ];then
        grep -vi recital /etc/odbc.ini  >> /tmp/$$
        mv /tmp/$$ /etc/odbc.ini
      fi
    fi
  fi
  cd ${DB_ROOT}
}
#
# Uninstall RDS specific files
dbuninstall_rds()
{
  cd ${DB_ROOT}setup
  ##############################################################
  # Stop the Recital port listener
  ##############################################################
  recitaladmin shutdown 1
  # Remove files
  recital_rm "${DB_ROOT}conf/"
  recital_rm  "/etc/pam.d/recital /etc/rc.d/init.d/recital /etc/init.d/recital"
  recital_delrsibase
  recital_delldconfig
  cd ${DB_ROOT}
}
#
# Uninstall RRS specific files
dbuninstall_rrs()
{
  cd ${DB_ROOT}setup
  recital_rm "replication.allow replication.deny" "${DB_ROOT}conf/"
  cd ${DB_ROOT}
}
#
# Uninstall RTD specific files
dbuninstall_rtd()
{
  cd ${DB_ROOT}setup
  recital_rm "termtab.db" "${DB_ROOT}conf/"
  ##############################################################
  # Remove desktop and menu shortcuts
  ##############################################################
  recital_delshortcut
  recital_delmenu
  #
  recital_delldconfig
  #
  cd ${DB_ROOT}
}
#
# Uninstall RWD specific files
dbuninstall_rwd()
{
  cd ${DB_ROOT}setup
  ##############################################################
  # Check for Apache the plugin
  ##############################################################
  if [ -f /etc/httpd/conf.d/recital.conf ];then
    rm /etc/httpd/modules/mod_recital.so    > /dev/null 2>&1
    rm /var/www/html/recital                > /dev/null 2>&1
    rm /etc/httpd/conf.d/recital.conf       > /dev/null 2>&1
    #
    ##############################################################
    # restart appache
    ##############################################################
    service httpd restart
  fi
  if [ -f /usr/lib/apache2/modules/mod_recital.so ];then
    rm /usr/lib/apache2/modules/mod_recital.so
  fi
  if [ -f /etc/apache2/mods-enabled/recital.conf ];then
    rm /etc/apache2/mods-enabled/recital.conf
  fi
  cd ${DB_ROOT}
}
#
# Update the specified environment variable
#
# $1 is the file that contains the environment variable
# $2 is the environment variable to update
# $3 is the old value
# $4 is the new value
#
recital_update_env()
{
  cat ${1} | sed -e s/${2}=${3}/${2}=${4}/ > /usr/tmp/$$
  mv /usr/tmp/$$ ${1}
}
#
# Show current value of envirionment varible and update with new value
#
# $1 - current value
# $2 - description
# $3 - file name to update
# $4 - variable name
# $5 - convert to upper case
# $6 - default if empty
#
installRRS_setenv()
{
  if [ -z "$1" ];then
    if [ "$5" = "1" ];then
      rep_default=`echo ${6} | tr [a-z] [A-Z]`
    else
      rep_default=${6}
    fi
  else
    if [ "$5" = "1" ];then
      rep_default=`echo ${1} | tr [a-z] [A-Z]`
    else
      rep_default=${1}
    fi
  fi
  rep_reply=$rep_default
  ${echonl_b} "$2: [${rep_reply}] $echonl_a"
  read rep_reply
  if [ -n "${rep_reply}" ];then
    if [ "$5" = "1" ];then
      rep_default=`echo ${rep_reply} | tr [a-z] [A-Z]`
    else
      rep_default=${rep_reply}
    fi
  fi
  if [ -z "$1" ];then
    if [ "$4" = "DB_PUBLISHER" ];then
      installRRS_add_publisher ${rep_default}
    elif [ "$4" = "DB_PUBLICATIONID" ];then
      installRRS_add_publicationid ${rep_default}
    elif [ "$4" = "DB_PEERS" ];then
      installRRS_add_peers ${rep_default}
    elif [ "$4" = "DB_REPTYPE" ];then
      installRRS_add_reptype ${rep_default}
    elif [ "$4" = "DB_REPDELAY" ];then
      installRRS_add_repdelay ${rep_default}
    fi
  elif [ "$1" != "${rep_default}" ];then
    recital_update_env "$3" "$4" "$1" "${rep_default}"
    if [ "$4" = "DB_PUBLISHER" ];then
      DB_PUBLISHER=${rep_default}
    elif [ "$4" = "DB_PUBLICATIONID" ];then
      DB_PUBLICATIONID=${rep_default}
    elif [ "$4" = "DB_PEERS" ];then
      DB_PEERS=${rep_default}
    elif [ "$4" = "DB_REPTYPE" ];then
      DB_REPTYPE=${rep_default}
    elif [ "$4" = "DB_REPDELAY" ];then
      DB_REPDELAY=${rep_default}
    fi
  fi
}
#
# Add the DB_PUBLICATIONID to the recital.conf file
#
# $1 is the vale to set
#
installRRS_add_publicationid()
{
  # Set default value if none given
  if [ -z "$1" ];then
     setvalue="0"
  else
     setvalue=$1
  fi
  echo "" >>  ${RECITAL_CONF}
  echo "#" >>  ${RECITAL_CONF}
  echo "#------------------------------------------------------------------------------" >>  ${RECITAL_CONF}
  echo "# configurable replication parameters" >>  ${RECITAL_CONF}
  echo "#------------------------------------------------------------------------------" >>  ${RECITAL_CONF}
  echo "# Every system that will publish data for replication must have a unique" >> ${RECITAL_CONF}
  echo "# publication ID. Once assigend for a system it should not be changed" >> ${RECITAL_CONF}
  echo "# This publication ID is used by all Recital products running on this system." >> ${RECITAL_CONF}
  echo "DB_PUBLICATIONID=$setvalue                          ;export DB_PUBLICATIONID" >> ${RECITAL_CONF}
  DB_PUBLICATIONID=$setvalue
}
#
# Add the DB_REPDIR to the recital.conf file
#
# $1 is the vale to set
#
installRRS_add_repdir()
{
  # Set default value if none given
  if [ -z "$1" ];then
     setvalue="${DB_DATADIR}replication/"
  else
     setvalue=$1
  fi
  echo "# This is the directory that the services will access files it requires." >> ${RECITAL_CONF}
  echo "# It must be the SAME path on all system." >> ${RECITAL_CONF}
   echo "DB_REPDIR=$setvalue                          ;export DB_REPDIR" >> ${RECITAL_CONF}
  DB_REPDIR=$setvalue
}
#
# Add the DB_SYNCNUM to the recital.conf file
#
# $1 is the vale to set
#
installRRS_add_syncnum()
{
  # Set default value if none given
  if [ -z "$1" ];then
     setvalue="FALSE"
  else
     setvalue=$1
  fi
  echo "# Used to enable/disable adding a unique number for replication to each row" >> ${RECITAL_CONF}
  echo "# of a table. If this is set to TRUE then the first time a table is opened" >> ${RECITAL_CONF}
  echo "# all the rows will be updated with a replication number." >> ${RECITAL_CONF}
  echo "DB_SYNCNUM=$setvalue                          ;export DB_SYNCNUM" >> ${RECITAL_CONF}
  DB_SYNCNUM=$setvalue
}
#
# Add the DB_REPTYPE to the recital.conf file
#
# $1 is the value to set
#
installRRS_add_reptype()
{
  # Set default value if none given
  if [ -z "$1" ];then
     setvalue="SLAVE"
  else
     setvalue=`echo $1 |  tr [a-z] [A-Z]`
  fi
  echo "# Used to define the mode that the subscriber service will operate in" >> ${RECITAL_CONF}
  echo "# when it starts. This variable is only used by the subscriber service." >> ${RECITAL_CONF}
  echo "# using -t PEER | MASTER | SLAVE on the command line when starting" >> ${RECITAL_CONF}
  echo "# the Service will overwrite this setting." >> ${RECITAL_CONF}
  echo "DB_REPTYPE=$setvalue                          ;export DB_REPTYPE" >> ${RECITAL_CONF}
  DB_REPTYPE=$setvalue
}
#
# Add the DB_PUBLISHER to the recital.conf file
#
# $1 is the value to set
#
installRRS_add_publisher()
{
  # Set default value if none given
  if [ -z "$1" ];then
     setvalue="localhost"
  else
     setvalue=$1
  fi
  echo "# Used to specify the publisher that subscriber service will connect to" >> ${RECITAL_CONF}
  echo "# when it starts. This variable is only used by the subscriber service." >> ${RECITAL_CONF}
  echo "DB_PUBLISHER=$setvalue                          ;export DB_PUBLISHER" >> ${RECITAL_CONF}
  DB_PUBLISHER=$setvalue
}
#
# Add the DB_PEERS to the recital.conf file
#
# $1 is the value to set
#
installRRS_add_peers()
{
  # Set default value if none given
  if [ -z "$1" ];then
     setvalue="localhost"
  else
     setvalue=$1
  fi
  echo "# Used to specify a comma separated list of replication peer systems that" >> ${RECITAL_CONF}
  echo "# have data to publish. This variable is only used by the publisher service." >> ${RECITAL_CONF}
  echo "# once the publisher service is started it will get data to publish from" >> ${RECITAL_CONF}
  echo "# list of servers specified." >> ${RECITAL_CONF}
  echo "DB_PEERS=$setvalue                          ;export DB_PEERS" >> ${RECITAL_CONF}
  DB_PEERS=$setvalue
}
#
# Add the DB_REPDELAY to the recital.conf file
#
# $1 is the value to set
#
installRRS_add_repdelay()
{
  # Set default value if none given
  if [ -z "$1" ];then
     setvalue="60"
  else
     setvalue=$1
  fi
  echo "# Used to specify the delay in seconds that the replication service will wait" >> ${RECITAL_CONF}
  echo "# before checking for new transactions." >> ${RECITAL_CONF}
  echo "# Using -d seconds on the command line when starting the service will overwrite" >> ${RECITAL_CONF}
  echo "# this setting." >> ${RECITAL_CONF}
  echo "# if no value is specified here or on the command line, then the default value" >> ${RECITAL_CONF}
  echo "# will be 60 seconds." >> ${RECITAL_CONF}
  echo "DB_REPDELAY=$setvalue                          ;export DB_REPDELAY" >> ${RECITAL_CONF}
  DB_REPDELAY=$setvalue
}
#
# Get the value for the DB_PUBLISHER and update it
#
installRRS_publisher()
{
    l_default="localhost"
    echo ""
    echo "Specify the node name or IP Address of the Publisher that you want to"
    echo "subscribe with."
    if [ "${DB_REPTYPE}" = "PEER" ];then
       echo "As you have selected Peer as the replication type, you can specify"
       echo "'${NODENAME}' as the publisher."
       echo "Doing this will make this system the master publisher and"
       echo "you will need to provide a list of peers."
       if [ -z "${DB_PUBLISHER}" ];then
          l_default=${NODENAME}
       fi
    fi
    installRRS_setenv "${DB_PUBLISHER}" "Publisher" ${RECITAL_CONF} "DB_PUBLISHER" 0 ${l_default}
}
#
# Get the value for the DB_REPDELAY and update it
#
installRRS_delay()
{
    echo ""
    echo "Specify the delay time in seconds that the service will pause between"
    echo "checking with the publication service."
    installRRS_setenv "${DB_REPDELAY}" "Delay" ${RECITAL_CONF} "DB_REPDELAY" 0 60
}
#
# Get the value for the DB_PUBLICATIONID and update it
#
installRRS_publicationid()
{
    echo ""
    echo "Please specify a unique publication ID greater than 0"
    installRRS_setenv "${DB_PUBLICATIONID}" "Publication ID" ${RECITAL_CONF} "DB_PUBLICATIONID" 0 1
}
#
# Create replication database
#
installRRS_create_database()
{
    recital_getprocess rsiserver
    if [ -n "${PROCESS}" ];then
       if [ "${1}" = "-r" -a -d ${DB_DATADIR}/replication ];then
          rm -f ${DB_DATADIR}/replication/*
       fi
       recitaladmin --execute ${DB_ROOT}setup/rrssetup
       rm -f ${DB_DATADIR}/replication*.dtd
    elif [ "${1}" != "1" -a -z "${3}"  ];then
      l_productname="Recital Database Server"
      if [ "${2}" != "1" ];then
        echo ""
        echo "Can't create replication database as the ${l_productname} is not running"
      fi
      recital_confirm_action "${l_productname}" "start" "y" "n"
      recitaladmin --server start
      installRRS_create_database ${1} ${2} 1
    fi
}
#
# install Recital into httpd.conf
#
dbinstall_rwd_update_httpd_conf()
{
  echo "#" > /tmp/$$
  installed=`grep mod_recital osxhttpd.conf`
  if [ -z "${installed}" ];then
    while read line;do
      if [ -z "${findloadmodule}" ];then
        loadmodule=`echo $line | grep "^LoadModule"`
        if [ -n "${loadmodule}" ]; then
          echo "LoadModule recital_module libexec/apache2/mod_recital.so" >> /tmp/$$
          findloadmodule=1
        fi
      fi
      if [ -z "${findaddhandler}" ];then
        if [ -n "${inminemodule}" ]; then
          addhandler=`echo $line | grep "#AddHandler"`
          if [ -n "${addhandler}" ]; then
            findaddhandler=1
            addhandlerfound=1
          fi
        else
          minemodule=`echo $line | grep "<IfModule mime_module>"`
          if [ -n "${minemodule}" ]; then
            inminemodule=1
          fi
        fi
      fi
      echo $line >> /tmp/$$
      if [ -n "${addhandlerfound}" ];then          echo "#" >> /tmp/$$
        echo "# Cause the Recital Firecat Server to handle files with a .rsp, .prg or .wsp" >> /tmp/$$
        echo "# extension." >> /tmp/$$
        echo "#" >> /tmp/$$
        echo "AddHandler recital-handler .rsp" >> /tmp/$$
        echo "AddHandler recital-handler .wsp" >> /tmp/$$
        echo "AddHandler recital-handler .prg" >> /tmp/$$
        addhandlerfound=""
      fi
    done < ${1}
  fi
  mv ${1} ${1}.sav
  mv /tmp/$$ ${1}
}
#
# return a file list
#
installRTD_filelist()
{
    FILELIST="db dbrt dbusers dbprint dbconvert dbdbf dbdbt dbdbx dbndx dbintegrity recitaladmin recitaldump recitalrestore"
}
#
# return a list of base products
#
installRDS_baselist()
{
    BASELIST="net rec rsi http odb"
}
#
# return a list of files
#
installRDS_filelist()
{
    FILELIST="recitaladmin http dbintegrity recitalserver recitaldump recitalrestore"
}
#
# Install Servers
#
installRDS_install_servers()
{
  if [ -z "$quiet" ]; then
    echo "install RDS: Relinking Servers."
  fi
  installRDS_baselist
  for i in $servers
  do
    case $i in
    net|NET)
      cwd=`pwd`
      cd ${DB_BINDIR}
      if [ "${quiet}" != "1" ];then
        echo "Installing the Recital Database Server on node ${nodename}."
      fi
      installRDS_chmod "${BASELIST}"
      cd ${cwd}
      ;;
    ingres|Ingres|INGRES)
      echo "Installing the Ingres server on node ${nodename}."
      recitalRDS_install_ingres
      echo "The Ingres server was successfully installed on node ${nodename}."
      exit
      ;;
    postgresql|PostgreSQL|POSTGRESQL)
      echo "Installing the PostgreSQL server on node ${nodename}."
      installRDS_chmod "pos"
      echo "The PostgreSQL server was successfully installed on node ${nodename}."
      exit;
      ;;
    mysql|MySQL|MYSQL)
      echo "Installing the MySQL server on node ${nodename}."
      installRDS_chmod "mys"
      echo "The MySQL server was successfully installed on node ${nodename}."
      exit;
      ;;
    oracle|Oracle|ORACLE)
      echo "Installing the Oracle server on node ${nodename}."
      installRDS_chmod "ora"
      echo "The Oracle server was successfully installed on node ${nodename}."
      exit;
      ;;
    db2|DB2)
      echo "Installing the DB2 server on node ${nodename}."
      installRDS_chmod "db2"
      echo "The DB2 server was successfully installed on node ${nodename}."
      ;;
    informix|Informix|INFORMIX)
      echo "Installing the Informix server on node ${nodename}."
      installRDS_chmod "inf"
      echo "The Informix server was successfully installed on node ${nodename}."
      ;;
    sybase|Sybase|SYBASE)
      echo "Installing the Sybase server on node ${nodename}."
      installRDS_chmod "syb"
      echo "The Sybase server was successfully installed on node ${nodename}."
      ;;
    esac
  done
}
#
# Change the permissions
#
# $1 product list
#
installRDS_chmod()
{
  for i in $1
  do
    if [ -f db_${i}server ];then
      recital_chmod "+t" db_${i}server
    fi
  done
}
#
# install Recital Server
#
dbinstall_rds()
{
  if [ -z "$3" ];then
    servers="net"
  else
    servers=$3
  fi
  nodename=`uname -n`;export nodename
  sunsystem=`uname -a | grep "SunOS"`
  if [ "${linux}" = "1" -o "${2}" = "1" ]; then
    quiet="true"
  else
    echo "Recital version ${fullver} Database Server Installation in progress."
  fi
  installRDS_filelist
  if [ "${quiet}" != "1" ];then
    echo "Installing the RSI Port server on node ${nodename}."
  fi
  #shut down RSI
  if [ -f /usr/bin/recitaladmin ];then
    recitaladmin shutdown 2> /dev/null
  fi
  #
  # Install the servers
  #
  installRDS_install_servers
  #
  #check services file for port server address
  recital_addrsibase
  if [ "${quiet}" != "1" ];then
    echo "The original copy of /etc/services has been moved to /etc/services.bck"
    echo "which you can remove at any time."
    echo ""
  fi
  #
  #   Install the RSI port server interface files.
  #
  if [ "${quiet}" != "1" ];then
   echo "Setting up interface files."
  fi
  recital_link "${FILELIST}"
  #
  # Install the services file
  #
  recital_addpamd
  recital_addinitd "recital" "recital"
  touch /etc/recital.d/.installedRDS
  recitaladmin start  0 1 0
  if [ "${quiet}" != "1" ];then
    echo "The Recital Database Server was successfully installed on node ${nodename}."
  fi
}
#
# install Recital
#
dbinstall_rtd()
{
	
  ##############################################################
  # Set up file protections
  ##############################################################
  cd ${DB_ROOT}bin
  installRTD_filelist
  recital_chmod "+t" "db.exe"
  recital_chmod "+x" "${DB_ROOT}terminals"
  recital_chmod "+x" "print.unix"
  recital_chmod "+x" "${FILELIST}"

  ##############################################################
  # Create links
  ##############################################################
  if [ "${quiet}" = "1" ]; then
    if [ "$3" = "0" ]; then
     DOLINKS="-a 0 = 1"
   else
     DOLINKS=""
   fi
  else
   if [ -f ./db ];then
     echo " "
     echo "NOTE"
     echo " "
     echo "You can optionally link the Recital files into the"
     echo "/usr/bin directory. If you do so, then there will be"
     echo "no need to add the Recital directory to the PATH. The"
     echo "Following files will be linked into /usr/bin, replacing"
     echo "any that may be there with the same name."
     echo " "
     cnt=0
     for i in ${FILELIST}
     do
        if [ ${cnt} = 6 ];then
           echo "    $i"
           cnt=0
        else
          ${echonl_b} "    $i"
          cnt=`expr ${cnt} + 1`
        fi
      done
      echo " "
      echo " "
      reply="y"
      ${echonl_b} "install RTD: Do you want to create links into /usr/bin? (y/n) [${reply}] : $echonl_a"
      read reply

      if [ -z "$reply" ];then
        reply="y"
      fi

      if [ "y" != "${reply}" ];then
        DOLINKS="-a 0 = 1"
      else
        echo "install RTD: Creating links to /usr/bin - Please wait."
        DOLINKS=""
      fi
    else
      DOLINKS="-a 0 = 1"
    fi
  fi

  ##############################################################
  # create user file
  ##############################################################
  if [ -f recitaladmin ];then
    if [ ! -f ${DB_ROOT}users/users.db ];then
     /usr/bin/recitaladmin users -c > /dev/null 2>&1
    fi
    /usr/bin/recitaladmin users -r > /dev/null 2>&1
  fi
  #
  ##############################################################
  # Add a desktop and menu shortcuts
  ##############################################################
  recital_addshortcut $1 $4
  recital_addmenu $1 $5
  touch /etc/recital.d/.installedRTD
}
#
# install Recital Clinet Drivers
#
dbinstall_rcd()
{
  cd ${DB_ROOT}/setup

  ##############################################################
  # Setup ODBC
  ##############################################################
  echo "# Recital ODBC Driver"                  				>  ${DB_ROOT}setup/odbcinst.ini
  echo "[Recital]"                                        		>> ${DB_ROOT}setup/odbcinst.ini
  echo "Description = Recital ODBC Driver"      				>> ${DB_ROOT}setup/odbcinst.ini
  echo "Driver = ${DB_ROOT}drivers/libodbc_recital.${slext}" 	>> ${DB_ROOT}setup/odbcinst.ini
  echo "Setup  = ${DB_ROOT}drivers/libodbc_recital.${slext}" 	>> ${DB_ROOT}setup/odbcinst.ini
  echo "FileUsage = 1"                                    		>> ${DB_ROOT}setup/odbcinst.ini


  if [ "${2}" != "none" ];then
    ##############################################################
    # Install unixODBC if required
    ##############################################################
    if [ "${2}" = "install" ];then
      cd /
      tar xf  ${DB_ROOT}setup/unixODBC.tar
      cd ${DB_ROOT}setup
    fi
    #
    ##############################################################
    # Check for ODBC driver manager installation and install
    ##############################################################
    if [ -f /usr/bin/iodbc-config -a "${2}" = "iODBC" ];then
      odbcinifile=`iodbc-config --odbcini`
      odbcinstfile=`iodbc-config --odbcinstini`
      odbcdir=`dirname ${odbcinstfile}`
      if [ ! -d ${odbcdir} ];then
         mkdir ${odbcdir}
      fi
      if [ -f ${odbcinstfile} ];then
        installed=`grep "\[Recital\]" ${odbcinstfile}`
        if [ -z "$installed" ];then
          echo "[ODBC Drivers]"                           >  /tmp/$$
          echo "Recital = Installed"                      >> /tmp/$$
          grep -v "\[ODBC Drivers\]" ${odbcinstfile}      >> /tmp/$$
          cat ${DB_ROOT}setup/odbcinst.ini               >> /tmp/$$
          mv /tmp/$$ ${odbcinstfile}
        fi
        installed=`grep "\[Recital ODBC test\]" ${odbcinifile}`
        if [ -z "$installed" ];then
          echo "[ODBC Data Sources]"                      >  /tmp/$$
          echo "Recital ODBC test = Recital"              >> /tmp/$$
          grep -v "\[ODBC Data Sources\]" ${odbcinifile}   >> /tmp/$$
          cat ${DB_ROOT}setup/odbc_test.ini              >> /tmp/$$
          mv /tmp/$$ ${odbcinifile}
        fi
      else
        echo "[ODBC Drivers]"                     >  ${odbcinstfile}
        echo "Recital = Installed"                >> ${odbcinstfile}
        cat ${DB_ROOT}setup/odbcinst.ini         >> ${odbcinstfile}
        echo "[ODBC Data Sources]"                >  ${odbcinifile}
        echo "Recital ODBC test = Recital"        >> ${odbcinifile}
        cat ${DB_ROOT}setup/odbc_test.ini        >> ${odbcinifile}
     fi

    elif [ -f /usr/bin/odbcinst ];then
      odbcinst -i -v -d -f ${DB_ROOT}setup/odbcinst.ini
      odbcinst -i -s -l -f ${DB_ROOT}setup/odbc_test.ini
    elif [ -f /usr/local/bin/odbcinst ];then
      /usr/local/bin/odbcinst -i -v -d -f ${DB_ROOT}setup/odbcinst.ini
      /usr/local/bin/odbcinst -i -s -l -f ${DB_ROOT}setup/odbc_test.ini
    elif [ -f /usr/lib/libodbc.so -o "${2}" = "unixODBC" ];then
      if [ -f /etc/odbcinst.ini ];then
        installed=`grep "\[Recital\]" /etc/odbcinst.ini`
        if [ -z $installed ];then
          cat ${DB_ROOT}setup/odbcinst.ini               >> /etc/odbcinst.ini
          cat ${DB_ROOT}setup/odbc_test.ini              >> /etc/odbc.ini
        fi
      else
        cp ${DB_ROOT}setup/odbcinst.ini /etc/odbcinst.ini
        cp ${DB_ROOT}setup/odbc_test.ini /etc/odbc.ini
      fi
    elif [ -f /usr/lib/libiodbc.so.2 -o "${2}" = "iODBC" ];then
      if [ -f /etc/odbcinst.ini ];then
        installed=`grep "\[Recital\]" /etc/odbcinst.ini`
        if [ -z "$installed" ];then
          echo "[ODBC Drivers]"                           >  /tmp/$$
          echo "Recital = Installed"                      >> /tmp/$$
          grep -v "\[ODBC Drivers\]" /etc/odbcinst.ini    >> /tmp/$$
          cat ${DB_ROOT}setup/odbcinst.ini               >> /tmp/$$
          mv /tmp/$$ /etc/odbcinst.ini
        fi
        installed=`grep "\[Recital ODBC test\]" /etc/odbc.ini`
        if [ -z "$installed" ];then
          echo "[ODBC Data Sources]"                      >  /tmp/$$
          echo "Recital ODBC test = Recital"              >> /tmp/$$
          grep -v "\[ODBC Data Sources\]" /etc/odbc.ini   >> /tmp/$$
          cat ${DB_ROOT}setup/odbc_test.ini              >> /tmp/$$
          mv /tmp/$$ /etc/odbc.ini
        fi
      else
        echo "[ODBC Drivers]"                     >  /etc/odbcinst.ini
        echo "Recital = Installed"                >> /etc/odbcinst.ini
        cat ${DB_ROOT}setup/odbcinst.ini         >> /etc/odbcinst.ini
        echo "[ODBC Data Sources]"                >  /etc/odbc.ini
        echo "Recital ODBC test = Recital"        >> /etc/odbc.ini
        cat ${DB_ROOT}setup/odbc_test.ini        >> /etc/odbc.ini
     fi
    else
      echo "Error: No ODBC Driver manager found."
    fi
  fi
  #
  ##############################################################
  # Setup JDBC
  ##############################################################
  cd ${DB_ROOT}examples/jdbc
  echo "# Change the specified paths to match your installation"                  >  RunTest
  echo "#CLASSPATH=/usr/java/jdk/jre/lib/rt.jar:.;export CLASSPATH"               >> RunTest
  echo "java -cp ${DB_ROOT}lib/RecitalJDBC.jar:. jdbc_test"                              >> RunTest
  echo "# Change the specified paths to match your installation"                  >  CompileTest
  echo "javac -classpath ${DB_ROOT}lib/RecitalJDBC.jar jdbc_test.java"   >> CompileTest
  chmod +x RunTest
  chmod +x CompileTest
  touch /etc/recital.d/.installedRCD
}
#
# install Recital web
#
dbinstall_rwd()
{
  cd ${DB_ROOT}/setup
  ##############################################################
  # Check for Apache version installed and install the plugin
  ##############################################################
  isinstalled=`whereis apachectl | grep "/"`
  if [ -n "${isinstalled}" ];then
	  apacheversion=`apachectl -v | grep Apache | cut -c 24-26`
	  if [ "${apacheversion}" = "2.2" ];then
	    if [ -d /etc/httpd/modules/ -a -d /etc/httpd/conf.d ];then
	      if [ -f ${DB_ROOT}lib/mod_recital2.2.so ];then
	        cp ${DB_ROOT}lib/mod_recital2.2.so /etc/httpd/modules/mod_recital.so
	      else
	        cp ${DB_ROOT}lib/mod_recital.so /etc/httpd/modules/mod_recital.so
	      fi
	      cp ${DB_ROOT}setup/recital.conf /etc/httpd/conf.d/
	    fi
	  elif [ "${apacheversion}" = "2.0" ];then
	    if [ -d /etc/httpd/modules/ -a -d /etc/httpd/conf.d ];then
	      if [ -f ${DB_ROOT}lib/mod_recital2.so ];then
	        cp ${DB_ROOT}lib/mod_recital2.so /etc/httpd/modules/mod_recital.so
	      else
	        cp ${DB_ROOT}lib/mod_recital.so /etc/httpd/modules/mod_recital.so
	      fi
	      cp ${DB_ROOT}setup/recital.conf /etc/httpd/conf.d/
	    fi
	  elif [ -d /etc/apache2/mods-enabled ];then
	    if [ -f ${DB_ROOT}lib/mod_recital2.2.so ];then
	      cp ${DB_ROOT}lib/mod_recital2.2.so /usr/lib/apache2/modules/mod_recital.so
	    elif [ -f ${DB_ROOT}lib/mod_recital2.so ];then
	      cp ${DB_ROOT}lib/mod_recital2.so /usr/lib/apache2/modules/mod_recital.so
	    else
	      cp ${DB_ROOT}lib/mod_recital.so /usr/lib/apache2/modules/mod_recital.so
	   fi
	   cp ${DB_ROOT}setup/recital.conf /etc/apache2/mods-enabled/
	  elif [  -d /usr/libexec/apache2 -a  -f /private/etc/apache2/httpd.conf ];then
	    dbinstall_rwd_update_httpd_conf "/private/etc/apache2/httpd.conf"
	    cp ${DB_ROOT}lib/mod_recital2.2.so /usr/libexec/apache2/mod_recital.so
	  else
	    exit
	 fi
	  if [ -d  /var/www/html ];then
	    if [ -h  /var/www/html/recital ];then
	      rm /var/www/html/recital
	    fi
	    ln -sf ${DB_ROOT}/webroot/recital /var/www/html/recital
	  fi
	  ##############################################################
	  # Check for restart Apache
	  ##############################################################
	  if [ "$2" = "2" ];then
	    apachectl restart  >/dev/null
	  fi
	  touch /etc/recital.d/.installedRWD
  fi
}
#
# install Recital repication
#
dbinstall_rs()
{
  if [ -f ${RECITAL_CONF} ];then
    . ${RECITAL_CONF}
  fi
  recital_getprocess pubservice service
  if [ -n "${PROCESS}" ];then
    recitaladmin replication stop
  else
    recital_getprocess subservice service
    if [ -n "${PROCESS}" ];then
       recitaladmin replication stop
    fi
  fi
  if [ "${2}" != "1" ];then
     askforinfo=1
  elif [ -z "${DB_REPTYPE}"  -a "${1}" = "-r" ];then
     askforinfo=1
  else
     askforinfo=0
  fi
  if [ "${askforinfo}" = "1" ];then
    echo "Specify the appropriate replication type for this installation."
    echo ""
    echo "SLAVE; This system will be a subscriber to a master publisher."
    echo "MASTER; This system will be a publisher for slave subscription services."
    echo "PEER; This system will be both a publisher and subscriber."
    installRRS_setenv "${DB_REPTYPE}" "Replication Type" ${RECITAL_CONF} "DB_REPTYPE" 1 "SLAVE"
    if [ "${DB_REPTYPE}" = "SLAVE" ];then
      installRRS_publicationid
      installRRS_publisher
      installRRS_delay
    elif [ "${DB_REPTYPE}" = "MASTER" ];then
      installRRS_publicationid
    elif [ "${DB_REPTYPE}" = "PEER" ];then
      installRRS_publicationid
      installRRS_publisher
      installRRS_delay
      if [ "${DB_PUBLISHER}" = "${NODENAME}" ];then
        echo ""
        echo "Please specify a comma separated list of the node names or IP Addresses"
        echo "of the Peers that will be published. You can specify "
        echo "'${NODENAME} if you wish to publish this system."
        installRRS_setenv "${DB_PEERS}" "Replication Peers" ${RECITAL_CONF} "DB_PEERS" 0 "localhost"
      fi
    else
      echo "${DB_REPTYPE} is an invalid replication type."
      recital_update_env ${RECITAL_CONF} DB_REPTYPE "${rep_default}" "${DB_REPTYPE}"
      exit
    fi
#    recital_update_env ${RECITAL_CONF} DB_SYNCNUM "FALSE" "TRUE"
  else
    if [ -z "${DB_PUBLICATIONID}" ];then
      installRRS_add_publicationid $4
    fi
    if [ -z "${DB_SYNCNUM}" ];then
      installRRS_add_syncnum TRUE
    fi
    if [ -z "${DB_REPTYPE}" ];then
      installRRS_add_reptype $3
    fi
    if [ -z "${DB_PUBLISHER}" ];then
      installRRS_add_publisher $5
    fi
    if [ -z "${DB_PEERS}" ];then
      installRRS_add_peers $6
    fi
    if [ -z "${DB_REPDELAY}" ];then
      installRRS_add_repdelay $7
    fi
  fi
  if [ -z "${DB_REPDIR}" ];then
     installRRS_add_repdir
  fi
  
  recital_addinitd "recitalrs" "recitalrs"
  
  installRRS_create_database ${1} ${2}
  touch /etc/recital.d/.installedRRS
  recital_link "recitalreplication"
}
#
# debugf ${FUNCNAME[0]} $LINENO 
#
debugf()
{
  echo "$1 line $2 $3" >> /tmp/recitalinstall.log
}
#
# some functions can be called as $1
if [ -n "$1" ];then
  if [ -n "$3" ];then
    scriptver=`echo $3 | cut -c 1``echo $3 | cut -c 3`
  fi
  case $1
  in
    recital_globalenv)
      $1 $2 $3
    ;;
  esac
fi

